@@ -6,7 +6,7 @@ use base 'Exporter';
 use File::Slurp;
 
 our @EXPORT = qw(ASTU_Wait ASTU_Read_Error_Log ASTU_Read_Access_Log
-		ASTU_Reset_Table ASTU_Module_Dir);
+		ASTU_Reset_Table ASTU_Module_Dir ASTU_Clear_Error_Log);
 
 sub ASTU_Wait {
 	my $dir = shift || "";
@@ -40,4 +40,9 @@ sub ASTU_Reset_Table {
 	$dbh->do("alter sequence $t\_id_seq restart with 1");
 }
 
+sub ASTU_Clear_Error_Log {
+	my $ef = ASTU_Module_Dir() . "/t/logs/error_log";
+	write_file($ef, "Cleared" . Carp::longmess());
+}
+
 1;
